@@ -14,16 +14,16 @@ from zope.i18nmessageid import MessageFactory
 
 from Products.Five import BrowserView
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone import PloneMessageFactory as plMF
+from Products.CMFPlone import PloneLocalesMessageFactory as PLMF
 from Products.CMFPlone import utils as CMFPloneUtils
+from Products.ATContentTypes import ATCTMessageFactory as ATMF
 
 from Solgema.fullcalendar.config import _
 from Solgema.fullcalendar import interfaces
 from Solgema.fullcalendar import log
 
 
-plMF = MessageFactory('plone')
-PLMF = MessageFactory('plonelocales')
-ATMF = MessageFactory('atcontenttypes')
 DTMF = MessageFactory('collective.z3cform.datetimewidget')
 
 def getCopyObjectsUID(REQUEST):
@@ -465,36 +465,37 @@ class SolgemaFullcalendarColorsCss(BrowserView):
         colorsDict = self.calendar.queryColors
         criterias = listBaseQueryTopicCriteria(self.context)
         css = ''
-        for criteria in criterias:
-            field = criteria.Field()
-            fieldid = str(field)
-            if not colorsDict.has_key(fieldid):
-                continue
+        if colorsDict:
+	    for criteria in criterias:
+		field = criteria.Field()
+		fieldid = str(field)
+		if not colorsDict.has_key(fieldid):
+		    continue
 
-            selectedItems = []
-            if criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion']:
-                selectedItems = criteria.getCriteriaItems()[0][1]['query']
-            elif criteria.meta_type == 'ATPortalTypeCriterion':
-                selectedItems = criteria.getCriteriaItems()[0][1]
+		selectedItems = []
+		if criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion']:
+		    selectedItems = criteria.getCriteriaItems()[0][1]['query']
+		elif criteria.meta_type == 'ATPortalTypeCriterion':
+		    selectedItems = criteria.getCriteriaItems()[0][1]
 
-            for i in range(len(selectedItems)):
-                cValName = selectedItems[i]
-                if not colorsDict[fieldid].has_key(cValName):
-                    continue
+		for i in range(len(selectedItems)):
+		    cValName = selectedItems[i]
+		    if not colorsDict[fieldid].has_key(cValName):
+			continue
 
-                color = colorsDict[fieldid][cValName]
-                if color:
-                    css += '#calendar .fc-event.%scolorIndex-%s {\n' % (fieldid, str(i))
-                    css += '    border:1px solid %s;\n' % (str(color))
-                    css += '}\n\n'
-                    css += '#calendar .fc-event.%scolorIndex-%s .fc-event-bg,\n' % (fieldid, str(i))
-                    css += '#calendar .fc-event.%scolorIndex-%s .fc-event-head,\n' % (fieldid, str(i))
-                    css += '#calendar .fc-event-hori.%scolorIndex-%s .fc-event-inner {\n' % (fieldid, str(i))
-                    css += '    background:none repeat scroll 0 0 %s;\n' % (str(color))
-                    css += '}\n\n'
-                    css += 'label.%scolorIndex-%s {\n' % (fieldid, str(i))
-                    css += '    color: %s;\n' % (str(color))
-                    css += '}\n\n'
+		    color = colorsDict[fieldid][cValName]
+		    if color:
+			css += '#calendar a.fc-event.%scolorIndex-%s {\n' % (fieldid, str(i))
+			css += '    border:1px solid %s;\n' % (str(color))
+			css += '}\n\n'
+			css += '#calendar a.fc-event.%scolorIndex-%s .fc-event-skin,\n' % (fieldid, str(i))
+			css += '#calendar a.fc-event.%scolorIndex-%s .fc-event-time {\n' % (fieldid, str(i))
+			css += '    background-color: %s;\n' % (str(color))
+			css += '    border-color: %s;\n' % (str(color))
+			css += '}\n\n'
+			css += 'label.%scolorIndex-%s {\n' % (fieldid, str(i))
+			css += '    color: %s;\n' % (str(color))
+			css += '}\n\n'
 
         return css
 
